@@ -11,9 +11,9 @@ expression.
 Usage::
 
     $ refile -h
-    $ refile [-r] ls [-h] PATTERN [DIR]
-    $ refile [-r] mv [-h] PATTERN REPLACE [DIR]
-    $ refile [-r] rm [-h] PATTERN [DIR]
+    $ refile [-rqvdli] ls [-h] PATTERN [DIR]
+    $ refile [-rqvdli] mv [-h] PATTERN REPLACE [DIR]
+    $ refile [-rqvdli] rm [-h] PATTERN [DIR]
 
 
 General Usage
@@ -47,6 +47,10 @@ Most options are global, they are:
 -q, --quiet             supress all output except errors
 -v, --verbose           print extra information
 -d, --directories       rename and delete (if empty) directories
+-l, --limit             maximum depth limit when searching recursively
+-i, --ignore            ignore any files which match this regex
+
+The only local options are for help on a specific command.
 
 
 Listing Files
@@ -54,7 +58,7 @@ Listing Files
 
 Usage::
 
-    $ refile ls [-h] PATTERN [DIR]
+    $ refile [-rqvdli] ls PATTERN [DIR]
 
 The ``ls`` subcommand lists all files in the directory ``DIR`` which match the
 regular expression ``PATTERN``. Internally this is run using the ``re.search``
@@ -71,7 +75,7 @@ Renaming Files
 
 Usage::
 
-    $ refile mv [-h] PATTERN REPLACE [DIR]
+    $ refile [-rqvdli] mv PATTERN REPLACE [DIR]
 
 The ``mv`` subcommand renames any file in the directory ``DIR`` which matches
 the regular expression ``PATTERN`` to the name ``RENAME``. This is run
@@ -94,7 +98,7 @@ Deleting Files
 
 Usage::
 
-    $ refile rm [-h] PATTERN [DIR]
+    $ refile [-rqvdli] rm PATTERN [DIR]
 
 The ``rm`` subcommand deletes all files in the directory ``DIR`` which match
 regular expression ``PATTERN``. The search is performed identically to the
@@ -107,3 +111,13 @@ Options
 -h, --help              print a useful help message
 
 """
+
+from __future__ import absolute_import, print_function
+
+__title__ = 'reFILE'
+__version__ = '0.2'
+__author__ = 'Sean Marshallsay'
+__email__ = 'srm.1708@gmail.com'
+__description__ = 'Utility for manipulating files via regex.'
+__homepage__ = 'https://github.com/Sean1708/reFILE'
+__download__ = 'https://github.com/Sean1708/reFILE.git'
