@@ -24,6 +24,21 @@ def setup_parser(parser):
         action='store_true',
         help='delete and rename directories'
     )
+    # use infinity as default so that limit can't be reached if not specified
+    parser.add_argument(
+        '-l', '--limit',
+        action='store',
+        type=int,
+        default=float('inf'),
+        help='maximum depth limit when searching recursively'
+    )
+    # if not specified use a regex which will not match anything
+    parser.add_argument(
+        '-i', '--ignore',
+        action='store',
+        default=r'(?!.*)',
+        help='ignore files matching this regex'
+    )
 
 
 def setup_print(subparsers):
